#
# spec file for package legion
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2016-2017 Christoph Junghans
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define git_ver .0.1ebd2fdc0da1

Name:           legion
Version:        18.05.0
Release:        bp156.3.6
Summary:        A data-centric parallel programming system
License:        Apache-2.0
Group:          Productivity/Networking/Other
Url:            http://legion.stanford.edu/
Source0:        %{name}-%{version}%{git_ver}.tar.gz
Patch0:         legion-fix-potential-return-of-random-data.patch
Patch1:         gcc-8.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

BuildRequires:  cmake
BuildRequires:  gasnet-devel
BuildRequires:  gcc-c++
BuildRequires:  openmpi-macros-devel
%ifarch x86_64 %{ix86}
BuildRequires:  libfabric-devel
%endif
%ifarch x86_64
BuildRequires:  libpsm2-devel
%endif
%openmpi_requires

%description
Legion is a data-centric parallel programming system for writing portable
high performance programs targeted at distributed heterogeneous architectures.

%package -n liblegion1
Summary:        Data-centric parallel programming system
Group:          System/Libraries

%description -n liblegion1
Legion is a data-centric parallel programming system for writing portable
high performance programs targeted at distributed heterogeneous architectures.
Legion presents abstractions which allow programmers to describe properties of
program data (e.g. independence, locality). By making the Legion programming
system aware of the structure of program data, it can automate many of the
tedious tasks programmers currently face, including correctly extracting task-
and data-level parallelism and moving data around complex memory hierarchies.
A novel mapping interface provides explicit programmer controlled placement of
data in the memory hierarchy and assignment of tasks to processors in a way that
is orthogonal to correctness, thereby enabling easy porting and tuning of Legion
applications to new architectures.

This package contains shared libraries for the legion library.

%package devel
Summary:        Development headers and libraries for the legion library
Group:          Development/Libraries/C and C++
Requires:       lib%{name}1 = %{version}
%openmpi_devel_requires

%description devel
Legion is a data-centric parallel programming system for writing portable
high performance programs targeted at distributed heterogeneous architectures.
Legion presents abstractions which allow programmers to describe properties of
program data (e.g. independence, locality). By making the Legion programming
system aware of the structure of program data, it can automate many of the
tedious tasks programmers currently face, including correctly extracting task-
and data-level parallelism and moving data around complex memory hierarchies.
A novel mapping interface provides explicit programmer controlled placement of
data in the memory hierarchy and assignment of tasks to processors in a way that
is orthogonal to correctness, thereby enabling easy porting and tuning of Legion
applications to new architectures.

This package contains development headers and libraries for the legion library.

%prep
%setup -q -n  %{name}-%{version}%{git_ver}
%patch0
%if 0%{suse_version} > 1500
# Workaround GCC8 bug in TW
%patch1 -p1
%endif

%build
%setup_openmpi
%{cmake} -DLegion_USE_HWLOC=OFF \
         -DLegion_USE_GASNet=ON \
         -DCOMPILER_SUPPORTS_MARCH=OFF \
         -DCOMPILER_SUPPORTS_MCPU=OFF \
         -DLegion_BUILD_EXAMPLES=ON \
         -DLegion_BUILD_TESTS=ON \
         -DLegion_ENABLE_TESTING=ON \
         -DGASNet_CONDUIT=mpi \
         -DLegion_BUILD_TUTORIAL=ON \
	 -DCMAKE_INSTALL_INCLUDEDIR:PATH=%{_includedir}/legion 
make

%install
%setup_openmpi
make -C build install DESTDIR=%{buildroot}

%check
%setup_openmpi
LD_LIBRARY_PATH="%{buildroot}/%{_libdir}:${LD_LIBRARY_PATH}" make -C build %{?_smp_mflags} test ARGS='-V'

%post -n liblegion1 -p /sbin/ldconfig
%postun -n liblegion1 -p /sbin/ldconfig

%files devel
%defattr(-,root,root,-)
%doc LICENSE.txt README.md CHANGES.txt
%{_includedir}/*
%{_libdir}/lib*.so
%{_datadir}/Legion

%files -n liblegion1
%defattr(-,root,root,-)
%doc LICENSE.txt README.md CHANGES.txt
%{_libdir}/lib*.so.1

%changelog
* Thu Oct 10 2019 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Disable hwloc support as legion is not compatible with hwloc >= 2.0
- Use new openmpi-macros-devel package to fecth openmpi dependencies
* Tue Jul 17 2018 junghans@votca.org
- Drop reproducible.patch and replace by CMake options
* Tue Jul 10 2018 bwiedemann@suse.com
- Add reproducible.patch to compile independent of build system CPU
  (boo#1100677)
* Wed Jun 13 2018 guillaume.gardet@opensuse.org
- Workaround GCC8 bug in TW with patch:
  * gcc-8.patch
* Mon Jun  4 2018 nmoreychaisemartin@suse.com
- Update to legion 18.05.0
  * Legion
  - Migrated all node-local Legion reservations to use Realm fast reservations and removed no longer necessary continuations
  - Added support for mapper attached data to all Mappable types
  - Added support for assigning a block of IDs to a library in a consistent way across nodes via generate_library_task_ids and friends
  * Realm
  - Added support for "fast" reservations that have better performance characteristics for reservations local to a node
  * C API
  - Updated projection functor API to match Legion C++ API
  * Regent
  - Regent now generates disjointness constraints for affine expressions in partition accesses. E.g. p[i] and p[i+1] are now known to be disjoint at compile time as long as p is a disjoint partition
  - Support for non-trivial projection functors in index space launches such as f(p[i+1])
  - Improvements to compile time spent in various optimization passes
  - Support for parallel compilation with the flag -fjobs N
  - Miscellaneous fixes
* Wed Feb  7 2018 nmoreychaisemartin@suse.com
- Update to legion 18.02.0
  * Legion
  - Support for PowerPC vector intrinsics
  - FieldAccessors support "view" coordinates and equivalent bounds checks
  - Improved schedule priorities for Legion meta-tasks
  * Realm
  - Operation priority can now be adjust after a task/copy is launched
  - Assorted bug/memory leak fixes
  - AffineAccessors support an optional translation from "view" coordinates
    to actual coordinates in the instance being accessed
  * Regent
  - Experimental support for calling Regent tasks from C/C++
  - Support for building with CMake
  - Support for running on PowerPC
  * Bindings
  - Obsolete Lua and Terra bindings have been removed. The remaining Terra
    bindings have been renamed to Regent and now produce libregent.so
* Fri Nov 10 2017 nmoreychaisemartin@suse.com
- Remove build parallelism as it uses too much memory
* Sat Oct 28 2017 junghans@votca.org
- Version bump to 17.10.0
  * Legion
  - Introduction of new partitioning API based on dependent partitioning
  - Deprecation of old partitioning API, LegionRuntime::{Arrays,Accessors} namespaces
  * Realm
  - Dependent partitioning API, including dimension-aware IndexSpace
  - Point/Rect types moved to Realm namespace
  - Instance creation allows caller to choose precise memory layout
  - Accessors moved to Realm namespace, changed to match new instance layouts
  * C API
  - The C API is now accessed via the legion.h header file. Note that this is still a redirect back to the current legion/legion_c.h header
  * Legion Prof
  - Added support for minimally invasive dumping of intermediate profiling data while the application is still running for long runs
  * Python
  - New Python API bindings and native support for Python processors
  - Compile with USE_PYTHON=1 and run with -ll:py 1 to enable Python
  - Also see examples/python_interop for an example
- Add legion-fix-potential-return-of-random-data.patch to workaround
  a rpmlint error
* Thu Oct  5 2017 nmoreychaisemartin@suse.com
- Force load of MPI environment
- Use OpenMPI2 instead of OpenMPI1 except for ppc64be (unsupported by OpenMPI >= 2)
* Tue Sep  5 2017 nmoreychaisemartin@suse.com
- Add _service to allow easier updates from github
* Fri Aug 25 2017 junghans@votca.org
- Version bump to 17.08.0
  * Build system
  - Added HDF_ROOT variable to customize HDF5 install location
  * Legion
  - New error message format and online reference at
    http://legion.stanford.edu/messages
  * Legion Prof
  - Added new compact binary format for profile logs
  - Added flag: -hl:prof_logfile prof_%%.gz
  * Realm
  - Fixes to support big-endian systems
  - Several performance improvements to DMA subsystem
  - Added REALM_DEFAULT_ARGS environment variable
    containing flags to be inserted at front of command line
  * Regent
  - Removed new operator. Unstructured regions are now
    fully allocated by default
  - Added optimization to automatically skip empty tasks
  - Initial support for extern tasks that are defined elsewhere
  - Tasks that use __demand(__openmp) are now constrained
    to run on OpenMP processors by default
  - RDIR: Better support for deeper nested region trees
- drop realm-detect-big-endian-systems-and-reverse-order-of-ID-fields.patch, upstream
- drop tutorial-fix-bad-type-size-causing-crash-on-big-endian-systems.patch, upstream
* Thu Jun 22 2017 nmoreychaisemartin@suse.com
- Fix support on big endian systems by adding:
  * realm-detect-big-endian-systems-and-reverse-order-of-ID-fields.patch
  * tutorial-fix-bad-type-size-causing-crash-on-big-endian-systems.patch
* Tue Jun 13 2017 nmoreychaisemartin@suse.com
- Disable build on ppc64 and s390x.
  See upstream bug https://github.com/StanfordLegion/legion/issues/265
* Fri May 26 2017 junghans@votca.org
- Version bump to 17.05.0: no changelog available
  * see https://github.com/StanfordLegion/legion/compare/legion-17.02.0...legion-17.05.0
* Fri Feb 24 2017 junghans@votca.org
- Version bump to 17.02.0
  * Drop 204.patch, merged upstream
* Tue Nov  1 2016 junghans@votca.org
- 204.patch: upstream patch to fix build on arm
* Sun Oct 30 2016 jengelh@inai.de
- Update descriptions. (Trim main description since only the SRPM
  will use it.)
* Fri Oct  7 2016 junghans@votca.org
- Update to v16.10
  * Dropped all merge patches
  * Realm
  - HDF5 support: moved to Realm module, added DMA channels
  - PAPI support: basic profiling (instructions, caches, branches) added
  * Build flow
  - Fixes to support compilation in 32-bit mode
  - Numerous improvements to CMake build
  * Regent
  - Improvements to vectorization of structured codes
  * Apps
  - Removed bit-rotted applications - some have been replaced by examples
    or Regent applications
  * Tests
  - New test infrastructure and top-level test script `test.py`
* Sat Sep  3 2016 junghans@votca.org
- v16.08.0 - initial import
